@@ -22,12 +22,14 @@ from unittest import mock
 import ddt
 from oslo_utils.fixture import uuidsentinel
 
+from tackerclient import client as root_client
 from tackerclient.common import exceptions
 from tackerclient.osc import utils as tacker_osc_utils
 from tackerclient.osc.v1.vnflcm import vnflcm
 from tackerclient.tests.unit.osc import base
 from tackerclient.tests.unit.osc.v1.fixture_data import client
 from tackerclient.tests.unit.osc.v1 import vnflcm_fakes
+from tackerclient.tests.unit.test_cli10 import MyResp
 from tackerclient.v1_0 import client as proxy_client
 
 
@@ -48,13 +50,13 @@ def _get_columns_vnflcm(action='create'):
     columns = ['ID', 'Instantiation State', 'VNF Instance Description',
                'VNF Instance Name', 'VNF Product Name', 'VNF Provider',
                'VNF Software Version', 'VNFD ID', 'VNFD Version', 'Links',
-               'VNF Configurable Properties']
+               'VNF Configurable Properties', 'VNF Package ID']
     if action == 'show':
         columns.extend(['Instantiated Vnf Info', 'VIM Connection Info'])
     if action == 'list':
         columns = [ele for ele in columns if ele not in
                    ['VNFD Version', 'VNF Instance Description',
-                    'VNF Configurable Properties']]
+                    'VNF Configurable Properties', 'VNF Package ID']]
         columns.remove('Links')
     return columns
 
@@ -157,25 +159,24 @@ class TestShowVnfLcm(TestVnfLcm):
 
 class TestListVnfLcm(TestVnfLcm):
 
-    vnf_instances = vnflcm_fakes.create_vnf_instances(count=3)
-
     def setUp(self):
         super(TestListVnfLcm, self).setUp()
         self.list_vnf_instance = vnflcm.ListVnfLcm(
             self.app, self.app_args, cmd_name='vnflcm list')
 
     def test_take_action(self):
+        vnf_instances = vnflcm_fakes.create_vnf_instances(count=3)
         parsed_args = self.check_parser(self.list_vnf_instance, [], [])
         self.requests_mock.register_uri(
             'GET', os.path.join(self.url, 'vnflcm/v1/vnf_instances'),
-            json=self.vnf_instances, headers=self.header)
+            json=vnf_instances, headers=self.header)
         actual_columns, data = self.list_vnf_instance.take_action(parsed_args)
 
         headers, columns = tacker_osc_utils.get_column_definitions(
             vnflcm._attr_map, long_listing=True)
 
         expected_data = []
-        for vnf_instance_obj in self.vnf_instances:
+        for vnf_instance_obj in vnf_instances:
             expected_data.append(vnflcm_fakes.get_vnflcm_data(
                 vnf_instance_obj, columns=columns, list_action=True))
 
@@ -184,6 +185,7 @@ class TestListVnfLcm(TestVnfLcm):
         self.assertCountEqual(expected_data, list(data))
 
     def test_take_action_with_pagination(self):
+        vnf_instances = vnflcm_fakes.create_vnf_instances(count=3)
         next_links_num = 3
         parsed_args = self.check_parser(self.list_vnf_instance, [], [])
         path = os.path.join(self.url, 'vnflcm/v1/vnf_instances')
@@ -195,18 +197,18 @@ class TestListVnfLcm(TestVnfLcm):
             links[i] = (
                 '{base_url}?nextpage_opaque_marker={vnf_instance_id}'.format(
                     base_url=path,
-                    vnf_instance_id=self.vnf_instances[i]['id']))
+                    vnf_instance_id=vnf_instances[i]['id']))
             link_headers[i] = copy.deepcopy(self.header)
             link_headers[i]['Link'] = '<{link_url}>; rel="next"'.format(
                 link_url=links[i])
 
         self.requests_mock.register_uri(
-            'GET', path, json=[self.vnf_instances[0]], headers=link_headers[0])
+            'GET', path, json=[vnf_instances[0]], headers=link_headers[0])
         self.requests_mock.register_uri(
-            'GET', links[0], json=[self.vnf_instances[1]],
+            'GET', links[0], json=[vnf_instances[1]],
             headers=link_headers[1])
         self.requests_mock.register_uri(
-            'GET', links[1], json=[self.vnf_instances[2]],
+            'GET', links[1], json=[vnf_instances[2]],
             headers=link_headers[2])
         self.requests_mock.register_uri(
             'GET', links[2], json=[], headers=self.header)
@@ -217,7 +219,7 @@ class TestListVnfLcm(TestVnfLcm):
             vnflcm._attr_map, long_listing=True)
 
         expected_data = []
-        for vnf_instance_obj in self.vnf_instances:
+        for vnf_instance_obj in vnf_instances:
             expected_data.append(vnflcm_fakes.get_vnflcm_data(
                 vnf_instance_obj, columns=columns, list_action=True))
 
@@ -297,9 +299,9 @@ class TestInstantiateVnfLcm(TestVnfLcm):
                                self.instantiate_vnf_lcm.take_action,
                                parsed_args)
 
-        expected_msg = ("Invalid input: File %s does not exist "
-                        "or user does not have read privileges to it")
-        self.assertEqual(expected_msg % sample_param_file, str(ex))
+        expected_msg = ("Invalid input: "
+                        "User does not have read privileges to it")
+        self.assertEqual(expected_msg, str(ex))
 
     @mock.patch("os.open")
     @mock.patch("os.access")
@@ -403,9 +405,9 @@ class TestHealVnfLcm(TestVnfLcm):
         ex = self.assertRaises(exceptions.InvalidInput,
                                self.heal_vnf_lcm.take_action, parsed_args)
 
-        expected_msg = ("Invalid input: File %s does not exist "
-                        "or user does not have read privileges to it")
-        self.assertEqual(expected_msg % sample_param_file, str(ex))
+        expected_msg = ("Invalid input: "
+                        "User does not have read privileges to it")
+        self.assertEqual(expected_msg, str(ex))
 
 
 @ddt.ddt
@@ -659,6 +661,45 @@ class TestUpdateVnfLcm(TestVnfLcm):
 
         self.assertEqual(expected_message, actual_message)
 
+    @mock.patch.object(proxy_client.ClientBase, 'deserialize')
+    def test_take_action_check_content_type(self, mock_des):
+        vnf_instance = vnflcm_fakes.vnf_instance_response()
+        sample_param_file = ('./tackerclient/osc/v1/vnflcm/samples/'
+                             'update_vnf_instance_param_sample.json')
+
+        arglist = [vnf_instance['id'], '--I', sample_param_file]
+        verifylist = [('vnf_instance', vnf_instance['id']),
+                      ('I', sample_param_file)]
+        mock_des.return_value = {}
+
+        # command param
+        parsed_args = self.check_parser(
+            self.update_vnf_lcm, arglist, verifylist)
+        url = os.path.join(self.url, 'vnflcm/v1/vnf_instances',
+                           vnf_instance['id'])
+
+        self.requests_mock.register_uri(
+            'PATCH', url, headers=self.header, json={})
+
+        sys.stdout = buffer = StringIO()
+
+        with mock.patch.object(root_client.HTTPClient,
+                               'do_request') as mock_req:
+            headers = {'Content-Type': 'application/json'}
+            mock_req.return_value = (MyResp(202, headers=headers), None)
+            self.update_vnf_lcm.take_action(parsed_args)
+            # check content_type
+            mock_req.assert_called_once_with(
+                f'/vnflcm/v1/vnf_instances/{vnf_instance["id"]}', 'PATCH',
+                body=mock.ANY, headers=mock.ANY,
+                content_type='application/merge-patch+json', accept='json')
+
+        actual_message = buffer.getvalue().strip()
+
+        expected_message = f'Update vnf:{vnf_instance["id"]}'
+
+        self.assertEqual(expected_message, actual_message)
+
     def test_take_action_param_file_not_exists(self):
         vnf_instance = vnflcm_fakes.vnf_instance_response()
         sample_param_file = "./not_exists.json"
@@ -774,9 +815,9 @@ class TestScaleVnfLcm(TestVnfLcm):
         ex = self.assertRaises(exceptions.InvalidInput,
                                self.scale_vnf_lcm.take_action, parsed_args)
 
-        expected_msg = ("Invalid input: File %s does not exist "
-                        "or user does not have read privileges to it")
-        self.assertEqual(expected_msg % sample_param_file, str(ex))
+        expected_msg = ("Invalid input: "
+                        "User does not have read privileges to it")
+        self.assertEqual(expected_msg, str(ex))
 
     @ddt.data('SCALE_IN', 'SCALE_OUT')
     def test_take_action_vnf_instance_not_found(self, scale_type):
@@ -888,9 +929,9 @@ class TestChangeExtConnVnfLcm(TestVnfLcm):
             self.change_ext_conn_vnf_lcm.take_action,
             parsed_args)
 
-        expected_msg = ("Invalid input: File %s does not exist "
-                        "or user does not have read privileges to it")
-        self.assertEqual(expected_msg % sample_param_file, str(ex))
+        expected_msg = ("Invalid input: "
+                        "User does not have read privileges to it")
+        self.assertEqual(expected_msg, str(ex))
 
     @mock.patch("os.open")
     @mock.patch("os.access")
